from a10sdk.common.A10BaseClass import A10BaseClass


class MatchList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param rewrite_to: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Rewrite to Destination URL String", "format": "string-rlx"}
    :param redirect_match: {"minLength": 1, "maxLength": 63, "type": "string", "description": "URL Matching (Pattern URL String)", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "match-list"
        self.DeviceProxy = ""
        self.rewrite_to = ""
        self.redirect_match = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class RedirectRewrite(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param redirect_secure_port: {"description": "Port (Port Number)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}
    :param redirect_secure: {"default": 0, "type": "number", "description": "Use HTTPS", "format": "flag"}
    :param match_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "rewrite-to": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Rewrite to Destination URL String", "format": "string-rlx"}, "redirect-match": {"minLength": 1, "maxLength": 63, "type": "string", "description": "URL Matching (Pattern URL String)", "format": "string-rlx"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "redirect-rewrite"
        self.DeviceProxy = ""
        self.redirect_secure_port = ""
        self.redirect_secure = ""
        self.match_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ResponseHeaderInsertList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param response_header_insert_type: {"enum": ["insert-if-not-exist", "insert-always"], "type": "string", "description": "'insert-if-not-exist': Only insert the header when it does not exist; 'insert-always': Always insert the header even when there is a header with the same name; ", "format": "enum"}
    :param response_header_insert: {"minLength": 1, "maxLength": 127, "type": "string", "description": "Insert a header into HTTP response (Header Content (Format: \"[name]: [value]\"))", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "response-header-insert-list"
        self.DeviceProxy = ""
        self.response_header_insert_type = ""
        self.response_header_insert = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ResponseHeaderEraseList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param response_header_erase: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Erase a header from HTTP response (Header Name)", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "response-header-erase-list"
        self.DeviceProxy = ""
        self.response_header_erase = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Template(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param logging: {"description": "Logging template (Logging Config name)", "format": "string", "minLength": 1, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/logging"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "template"
        self.DeviceProxy = ""
        self.logging = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class UrlSwitching(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param url_service_group: {"description": "Create a Service Group comprising Servers (Service Group Name)", "format": "string-rlx", "minLength": 1, "maxLength": 127, "type": "string", "$ref": "/axapi/v3/slb/service-group"}
    :param url_match_string: {"minLength": 1, "maxLength": 63, "type": "string", "description": "URL String", "format": "string-rlx"}
    :param url_switching_type: {"enum": ["contains", "ends-with", "equals", "starts-with", "url-case-insensitive", "url-hits-enable"], "type": "string", "description": "'contains': Select service group if URL string contains another string; 'ends-with': Select service group if URL string ends with another string; 'equals': Select service group if URL string equals another string; 'starts-with': Select service group if URL string starts with another string; 'url-case-insensitive': Case insensitive URL switching; 'url-hits-enable': Enables URL Hits; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "url-switching"
        self.DeviceProxy = ""
        self.url_service_group = ""
        self.url_match_string = ""
        self.url_switching_type = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class HostSwitching(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param host_switching_type: {"enum": ["contains", "ends-with", "starts-with", "host-hits-enable"], "type": "string", "description": "'contains': Select service group if hostname contains another string; 'ends-with': Select service group if hostname ends with another string; 'starts-with': Select service group if hostname starts with another string; 'host-hits-enable': Enables Host Hits counters; ", "format": "enum"}
    :param host_service_group: {"description": "Create a Service Group comprising Servers (Service Group Name)", "format": "string-rlx", "minLength": 1, "maxLength": 127, "type": "string", "$ref": "/axapi/v3/slb/service-group"}
    :param host_match_string: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Hostname String", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "host-switching"
        self.DeviceProxy = ""
        self.host_switching_type = ""
        self.host_service_group = ""
        self.host_match_string = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ResponseContentReplaceList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param response_new_string: {"minLength": 1, "maxLength": 127, "type": "string", "description": "String will be in the http content", "format": "string-rlx"}
    :param response_content_replace: {"minLength": 1, "maxLength": 127, "type": "string", "description": "replace the data from HTTP response content (String in the http content need to be replaced)", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "response-content-replace-list"
        self.DeviceProxy = ""
        self.response_new_string = ""
        self.response_content_replace = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class RequestHeaderInsertList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param request_header_insert_type: {"enum": ["insert-if-not-exist", "insert-always"], "type": "string", "description": "'insert-if-not-exist': Only insert the header when it does not exist; 'insert-always': Always insert the header even when there is a header with the same name; ", "format": "enum"}
    :param request_header_insert: {"minLength": 1, "maxLength": 127, "type": "string", "description": "Insert a header into HTTP request (Header Content (Format: \"[name]: [value]\"))", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "request-header-insert-list"
        self.DeviceProxy = ""
        self.request_header_insert_type = ""
        self.request_header_insert = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class RequestHeaderEraseList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param request_header_erase: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Erase a header from HTTP request (Header Name)", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "request-header-erase-list"
        self.DeviceProxy = ""
        self.request_header_erase = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class CompressionContentType(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param content_type: {"minLength": 1, "maxLength": 31, "type": "string", "description": "Compression content-type", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "compression-content-type"
        self.DeviceProxy = ""
        self.content_type = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class CompressionExcludeUri(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param exclude_uri: {"minLength": 1, "maxLength": 31, "type": "string", "description": "Compression exclude uri", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "compression-exclude-uri"
        self.DeviceProxy = ""
        self.exclude_uri = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class CompressionExcludeContentType(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param exclude_content_type: {"minLength": 1, "maxLength": 31, "type": "string", "description": "Compression exclude content-type (Compression exclude content type)", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "compression-exclude-content-type"
        self.DeviceProxy = ""
        self.exclude_content_type = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Http(A10BaseClass):
    
    """Class Description::
    HTTP.

    Class http supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param keep_client_alive: {"default": 0, "optional": true, "type": "number", "description": "Keep client alive", "format": "flag"}
    :param compression_auto_disable_on_high_cpu: {"description": "Auto-disable software compression on high cpu usage (Disable compression if cpu usage is above threshold. Default is off.)", "format": "number", "type": "number", "maximum": 100, "minimum": 1, "optional": true}
    :param req_hdr_wait_time: {"default": 0, "optional": true, "type": "number", "description": "HTTP request header wait time before abort connection", "format": "flag"}
    :param compression_enable: {"default": 0, "optional": true, "type": "number", "description": "Enable Compression", "format": "flag"}
    :param compression_keep_accept_encoding: {"default": 0, "optional": true, "type": "number", "description": "Keep accept encoding", "format": "flag"}
    :param failover_url: {"description": "Failover to this URL (Failover URL Name)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}
    :param compression_level: {"description": "compression level, default 1 (compression level value, default is 1)", "format": "number", "type": "number", "maximum": 9, "minimum": 1, "optional": true}
    :param insert_client_port_header_name: {"description": "HTTP Header Name for inserting Client Port", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param url_hash_last: {"description": "Use the end part of URL to calculate hash value (URL string length to calculate hash value)", "format": "number", "optional": true, "maximum": 128, "minimum": 4, "not": "url-hash-first", "type": "number"}
    :param use_server_status: {"default": 0, "optional": true, "type": "number", "description": "Use Server-Status header to do URL hashing", "format": "flag"}
    :param req_hdr_wait_time_val: {"description": "Number of seconds wait for client request header (default is 7)", "format": "number", "default": 7, "optional": true, "maximum": 31, "minimum": 1, "type": "number"}
    :param response_header_insert_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"response-header-insert-type": {"enum": ["insert-if-not-exist", "insert-always"], "type": "string", "description": "'insert-if-not-exist': Only insert the header when it does not exist; 'insert-always': Always insert the header even when there is a header with the same name; ", "format": "enum"}, "response-header-insert": {"minLength": 1, "maxLength": 127, "type": "string", "description": "Insert a header into HTTP response (Header Content (Format: \"[name]: [value]\"))", "format": "string-rlx"}, "optional": true}}]}
    :param insert_client_port: {"default": 0, "optional": true, "type": "number", "description": "Insert Client Port address into HTTP header", "format": "flag"}
    :param retry_on_5xx_per_req: {"description": "Retry http request on HTTP 5xx code for each request", "format": "flag", "default": 0, "optional": true, "not": "retry-on-5xx", "type": "number"}
    :param url_hash_offset: {"description": "Skip part of URL to calculate hash value (Offset of the URL string)", "format": "number", "type": "number", "maximum": 255, "minimum": 0, "optional": true}
    :param client_port_hdr_replace: {"default": 0, "optional": true, "type": "number", "description": "Replace the existing header", "format": "flag"}
    :param non_http_bypass: {"default": 0, "optional": true, "type": "number", "description": "Bypass non-http traffic instead of dropping", "format": "flag"}
    :param response_header_erase_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"response-header-erase": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Erase a header from HTTP response (Header Name)", "format": "string-rlx"}, "optional": true}}]}
    :param insert_client_ip: {"default": 0, "optional": true, "type": "number", "description": "Insert Client IP address into HTTP header", "format": "flag"}
    :param url_switching: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"url-service-group": {"description": "Create a Service Group comprising Servers (Service Group Name)", "format": "string-rlx", "minLength": 1, "maxLength": 127, "type": "string", "$ref": "/axapi/v3/slb/service-group"}, "url-match-string": {"minLength": 1, "maxLength": 63, "type": "string", "description": "URL String", "format": "string-rlx"}, "optional": true, "url-switching-type": {"enum": ["contains", "ends-with", "equals", "starts-with", "url-case-insensitive", "url-hits-enable"], "type": "string", "description": "'contains': Select service group if URL string contains another string; 'ends-with': Select service group if URL string ends with another string; 'equals': Select service group if URL string equals another string; 'starts-with': Select service group if URL string starts with another string; 'url-case-insensitive': Case insensitive URL switching; 'url-hits-enable': Enables URL Hits; ", "format": "enum"}}}]}
    :param host_switching: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"host-switching-type": {"enum": ["contains", "ends-with", "starts-with", "host-hits-enable"], "type": "string", "description": "'contains': Select service group if hostname contains another string; 'ends-with': Select service group if hostname ends with another string; 'starts-with': Select service group if hostname starts with another string; 'host-hits-enable': Enables Host Hits counters; ", "format": "enum"}, "host-service-group": {"description": "Create a Service Group comprising Servers (Service Group Name)", "format": "string-rlx", "minLength": 1, "maxLength": 127, "type": "string", "$ref": "/axapi/v3/slb/service-group"}, "host-match-string": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Hostname String", "format": "string-rlx"}, "optional": true}}]}
    :param strict_transaction_switch: {"default": 0, "optional": true, "type": "number", "description": "Force server selection on every HTTP request", "format": "flag"}
    :param response_content_replace_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "response-new-string": {"minLength": 1, "maxLength": 127, "type": "string", "description": "String will be in the http content", "format": "string-rlx"}, "response-content-replace": {"minLength": 1, "maxLength": 127, "type": "string", "description": "replace the data from HTTP response content (String in the http content need to be replaced)", "format": "string-rlx"}}}]}
    :param request_header_insert_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "request-header-insert-type": {"enum": ["insert-if-not-exist", "insert-always"], "type": "string", "description": "'insert-if-not-exist': Only insert the header when it does not exist; 'insert-always': Always insert the header even when there is a header with the same name; ", "format": "enum"}, "request-header-insert": {"minLength": 1, "maxLength": 127, "type": "string", "description": "Insert a header into HTTP request (Header Content (Format: \"[name]: [value]\"))", "format": "string-rlx"}}}]}
    :param compression_minimum_content_length: {"description": "Minimum Content Length (Minimum content length for compression in bytes. Default is 120.)", "format": "number", "default": 120, "optional": true, "maximum": 2147483647, "minimum": 1, "type": "number"}
    :param request_header_erase_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "request-header-erase": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Erase a header from HTTP request (Header Name)", "format": "string-rlx"}}}]}
    :param request_line_case_insensitive: {"default": 0, "optional": true, "type": "number", "description": "Parse http request line as case insensitive", "format": "flag"}
    :param url_hash_persist: {"default": 0, "optional": true, "type": "number", "description": "Use URL's hash value to select server", "format": "flag"}
    :param retry_on_5xx_per_req_val: {"description": "Number of times to retry (default is 3)", "format": "number", "default": 3, "optional": true, "maximum": 3, "minimum": 1, "type": "number"}
    :param bypass_sg: {"description": "Select service group for non-http traffic (Service Group Name)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "type": "string", "$ref": "/axapi/v3/slb/service-group"}
    :param name: {"description": "HTTP Template Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param retry_on_5xx_val: {"description": "Number of times to retry (default is 3)", "format": "number", "default": 3, "optional": true, "maximum": 3, "minimum": 1, "type": "number"}
    :param url_hash_first: {"description": "Use the begining part of URL to calculate hash value (URL string length to calculate hash value)", "format": "number", "optional": true, "maximum": 128, "minimum": 4, "not": "url-hash-last", "type": "number"}
    :param compression_keep_accept_encoding_enable: {"default": 0, "optional": true, "type": "number", "description": "Enable Server Accept Encoding", "format": "flag"}
    :param client_ip_hdr_replace: {"default": 0, "optional": true, "type": "number", "description": "Replace the existing header", "format": "flag"}
    :param compression_content_type: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "content-type": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Compression content-type", "format": "string-rlx"}}}]}
    :param log_retry: {"default": 0, "optional": true, "type": "number", "description": "log when HTTP request retry", "format": "flag"}
    :param insert_client_ip_header_name: {"description": "HTTP Header Name for inserting Client IP", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param compression_exclude_uri: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "exclude-uri": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Compression exclude uri", "format": "string-rlx"}}}]}
    :param retry_on_5xx: {"description": "Retry http request on HTTP 5xx code", "format": "flag", "default": 0, "optional": true, "not": "retry-on-5xx-per-req", "type": "number"}
    :param term_11client_hdr_conn_close: {"default": 0, "optional": true, "type": "number", "description": "Terminate HTTP 1.1 client when req has Connection: close", "format": "flag"}
    :param compression_exclude_content_type: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"exclude-content-type": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Compression exclude content-type (Compression exclude content type)", "format": "string-rlx"}, "optional": true}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/template/http/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "http"
        self.a10_url="/axapi/v3/slb/template/http/{name}"
        self.DeviceProxy = ""
        self.keep_client_alive = ""
        self.compression_auto_disable_on_high_cpu = ""
        self.req_hdr_wait_time = ""
        self.compression_enable = ""
        self.compression_keep_accept_encoding = ""
        self.failover_url = ""
        self.redirect_rewrite = {}
        self.compression_level = ""
        self.insert_client_port_header_name = ""
        self.url_hash_last = ""
        self.use_server_status = ""
        self.req_hdr_wait_time_val = ""
        self.response_header_insert_list = []
        self.insert_client_port = ""
        self.retry_on_5xx_per_req = ""
        self.url_hash_offset = ""
        self.client_port_hdr_replace = ""
        self.non_http_bypass = ""
        self.response_header_erase_list = []
        self.insert_client_ip = ""
        self.template = {}
        self.url_switching = []
        self.host_switching = []
        self.strict_transaction_switch = ""
        self.response_content_replace_list = []
        self.request_header_insert_list = []
        self.compression_minimum_content_length = ""
        self.request_header_erase_list = []
        self.request_line_case_insensitive = ""
        self.url_hash_persist = ""
        self.retry_on_5xx_per_req_val = ""
        self.bypass_sg = ""
        self.name = ""
        self.retry_on_5xx_val = ""
        self.url_hash_first = ""
        self.compression_keep_accept_encoding_enable = ""
        self.client_ip_hdr_replace = ""
        self.compression_content_type = []
        self.log_retry = ""
        self.insert_client_ip_header_name = ""
        self.compression_exclude_uri = []
        self.retry_on_5xx = ""
        self.term_11client_hdr_conn_close = ""
        self.compression_exclude_content_type = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class IcmpRateLimit(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param lockup: {"description": "Enter lockup state when ICMP rate exceeds lockup rate limit (Maximum rate limit. If exceeds this limit, drop all ICMP packet for a time period)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}
    :param lockup_period: {"description": "Maximum rate limit. If exceeds this limit, drop all ICMP packet for a time period", "minimum": 1, "type": "number", "maximum": 16383, "format": "number"}
    :param normal: {"description": "Normal rate limit. If exceeds this limit, drop the ICMP packet that goes over the limit", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "icmp-rate-limit"
        self.DeviceProxy = ""
        self.lockup = ""
        self.lockup_period = ""
        self.normal = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Icmpv6RateLimit(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param lockup_period_v6: {"description": "Lockup period (second)", "minimum": 1, "type": "number", "maximum": 16383, "format": "number"}
    :param normal_v6: {"description": "Normal rate limit. If exceeds this limit, drop the ICMP packet that goes over the limit", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}
    :param lockup_v6: {"description": "Enter lockup state when ICMP rate exceeds lockup rate limit (Maximum rate limit. If exceeds this limit, drop all ICMP packet for a time period)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "icmpv6-rate-limit"
        self.DeviceProxy = ""
        self.lockup_period_v6 = ""
        self.normal_v6 = ""
        self.lockup_v6 = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class AccessList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param acl_name: {"minLength": 1, "maxLength": 16, "type": "string", "description": "Named Access List", "format": "string"}
    :param acl_id: {"description": "ACL id", "format": "number", "maximum": 199, "minimum": 1, "type": "number", "$ref": "/axapi/v3/access-list/standard"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "access-list"
        self.DeviceProxy = ""
        self.acl_name = ""
        self.acl_id = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ddos(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param outside: {"default": 0, "type": "number", "description": "DDoS inside (trusted) or outside (untrusted) interface", "format": "flag"}
    :param inside: {"default": 0, "type": "number", "description": "DDoS inside (trusted) or outside (untrusted) interface", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ddos"
        self.DeviceProxy = ""
        self.outside = ""
        self.inside = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ve(A10BaseClass):
    
    """Class Description::
    Virtual ethernet interface.

    Class ve supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param name: {"description": "Name for the interface", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 32, "type": "string"}
    :param trap_source: {"default": 0, "optional": true, "type": "number", "description": "The trap source", "format": "flag"}
    :param mtu: {"platform-specific-range": 1, "platform-specific-default": 1, "description": "Interface mtu (Interface MTU, default 1500 (min MTU is 1280 for IPv6))", "format": "number", "optional": true, "type": "number"}
    :param ifnum: {"optional": false, "$ref": "/axapi/v3/network/vlan", "type": "number", "description": "Virtual ethernet interface number", "format": "number"}
    :param action: {"optional": true, "enum": ["enable", "disable"], "type": "string", "description": "'enable': Enable; 'disable': Disable; ", "format": "enum"}
    :param l3_vlan_fwd_disable: {"default": 0, "optional": true, "type": "number", "description": "Disable L3 forwarding between VLANs for incoming packets on this interface", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/interface/ve/{ifnum}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "ifnum"]

        self.b_key = "ve"
        self.a10_url="/axapi/v3/interface/ve/{ifnum}"
        self.DeviceProxy = ""
        self.icmp_rate_limit = {}
        self.isis = {}
        self.name = ""
        self.trap_source = ""
        self.bfd = {}
        self.ip = {}
        self.icmpv6_rate_limit = {}
        self.mtu = ""
        self.access_list = {}
        self.ifnum = ""
        self.lw_4o6 = {}
        self.ipv6 = {}
        self.action = ""
        self.l3_vlan_fwd_disable = ""
        self.ddos = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class SessionList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param protocol: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param forward_source: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param age: {"type": "number", "format": "number"}
    :param app_type: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param forward_dest: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param flags: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param hash: {"type": "number", "format": "number"}
    :param reverse_source: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param reverse_dest: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "session-list"
        self.DeviceProxy = ""
        self.protocol = ""
        self.forward_source = ""
        self.age = ""
        self.app_type = ""
        self.forward_dest = ""
        self.flags = ""
        self.A10WW_hash = ""
        self.reverse_source = ""
        self.reverse_dest = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param dst_ipv4_addr: {"type": "string", "format": "ipv4-address"}
    :param src_ipv6_addr: {"type": "string", "format": "ipv6-address"}
    :param src_port: {"type": "number", "format": "number"}
    :param dst_ipv6_addr: {"type": "string", "format": "ipv6-address"}
    :param name_str: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param total_sessions: {"type": "number", "format": "number"}
    :param src_ipv4_addr: {"type": "string", "format": "ipv4-address"}
    :param filter_type: {"enum": ["ipv4", "ipv6", "nat44", "nat64", "persist-ipv6-srcp-ip", "persist-ipv6-dst-ip", "persist-ipv6-ssl-id", "persist-dst-ip", "persist-src-ip", "persist-uie", "persist-ssl-id", "radius", "rserver", "vserver", "sip", "sixrd", "filter", "ds-lite", "dns-id-switch", "lsn"], "type": "string", "format": "enum"}
    :param session_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"protocol": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "forward-source": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "age": {"type": "number", "format": "number"}, "app-type": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "forward-dest": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "flags": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "hash": {"type": "number", "format": "number"}, "reverse-source": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "optional": true, "reverse-dest": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}}}]}
    :param dest_port: {"type": "number", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.dst_ipv4_addr = ""
        self.src_ipv6_addr = ""
        self.src_port = ""
        self.dst_ipv6_addr = ""
        self.name_str = ""
        self.total_sessions = ""
        self.src_ipv4_addr = ""
        self.filter_type = ""
        self.session_list = []
        self.dest_port = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Sessions(A10BaseClass):
    
    """Class Description::
    Operational Status for the object sessions.

    Class sessions supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/sessions/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "sessions"
        self.a10_url="/axapi/v3/sessions/oper"
        self.DeviceProxy = ""
        self.oper = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Rules(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param geo_location: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify geo-location name", "format": "string"}
    :param icmp_type: {"description": "ICMP type number", "format": "number", "maximum": 254, "minimum": 0, "not": "any-type", "type": "number"}
    :param ip: {"default": 0, "not-list": ["tcp", "udp", "service-obj-group"], "type": "number", "description": "Any Internet Protocol", "format": "flag"}
    :param service_obj_group: {"description": "Service object group (Source object group name)", "format": "string", "minLength": 1, "not-list": ["tcp", "udp", "ip"], "maxLength": 63, "type": "string"}
    :param dst_eq: {"description": "Match only packets on a given destination port (port number)", "format": "number", "not-list": ["dst-gt", "dst-lt"], "maximum": 65535, "minimum": 1, "type": "number"}
    :param tcp: {"default": 0, "not-list": ["udp", "ip", "service-obj-group"], "type": "number", "description": "protocol TCP", "format": "flag"}
    :param src_range: {"description": "match only packets in the range of port numbers (Starting Port Number)", "format": "number", "not-list": ["src-eq", "src-gt"], "maximum": 65535, "minimum": 1, "type": "number"}
    :param any_code: {"default": 0, "not": "icmp-code", "type": "number", "description": "Any ICMP code", "format": "flag"}
    :param src_lt: {"description": "Match only packets with a lower port number", "format": "number", "not-list": ["src-eq", "src-gt"], "maximum": 65535, "minimum": 2, "type": "number"}
    :param src_mask: {"type": "string", "description": "Source Mask 0=apply 255=ignore", "format": "ipv4-rev-netmask"}
    :param src_port_end: {"description": "Ending Port Number", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}
    :param dst_port_end: {"description": "Edning Destination Port Number", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}
    :param dst_range: {"description": "Match only packets in the range of port numbers (Starting Destination Port Number)", "format": "number", "not-list": ["dst-eq", "dst-gt"], "maximum": 65535, "minimum": 1, "type": "number"}
    :param established: {"default": 0, "type": "number", "description": "TCP established", "format": "flag"}
    :param dst_mask: {"type": "string", "description": "Destination Mask 0=apply 255=ignore", "format": "ipv4-rev-netmask"}
    :param seq_num: {"description": "Sequence Number", "minimum": 1, "type": "number", "maximum": 8192, "format": "number"}
    :param src_any: {"default": 0, "not-list": ["src-host", "src-object-group"], "type": "number", "description": "Any source host", "format": "flag"}
    :param fragments: {"default": 0, "type": "number", "description": "IP fragments", "format": "flag"}
    :param icmp_code: {"description": "ICMP code number", "format": "number", "maximum": 254, "minimum": 0, "not": "any-code", "type": "number"}
    :param src_gt: {"description": "Match only packets with a greater port number", "format": "number", "not-list": ["src-eq", "src-lt"], "maximum": 65534, "minimum": 1, "type": "number"}
    :param udp: {"default": 0, "not-list": ["tcp", "ip", "service-obj-group"], "type": "number", "description": "protocol UDP", "format": "flag"}
    :param dst_subnet: {"not-list": ["dst-any", "dst-host"], "type": "string", "description": "Destination Address", "format": "ipv4-address"}
    :param src_subnet: {"not-list": ["src-any", "src-host"], "type": "string", "description": "Source Address", "format": "ipv4-address"}
    :param vlan: {"description": "VLAN ID", "minimum": 1, "type": "number", "maximum": 4094, "format": "number"}
    :param dscp: {"description": "DSCP", "minimum": 1, "type": "number", "maximum": 63, "format": "number"}
    :param dst_lt: {"description": "Match only packets with a lesser port number", "format": "number", "not-list": ["dst-eq", "dst-gt"], "maximum": 65535, "minimum": 2, "type": "number"}
    :param icmp: {"default": 0, "not-list": ["tcp", "udp", "ip", "service-obj-group"], "type": "number", "description": "Internet Control Message Protocol", "format": "flag"}
    :param dst_gt: {"description": "Match only packets with a greater port number", "format": "number", "not-list": ["dst-eq", "dst-lt"], "maximum": 65534, "minimum": 1, "type": "number"}
    :param acl_log: {"default": 0, "type": "number", "description": "Log matches against this entry", "format": "flag"}
    :param src_object_group: {"description": "Network object group (Source network object group name)", "format": "string", "minLength": 1, "not-list": ["src-any", "src-host"], "maxLength": 63, "type": "string"}
    :param remark: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Access list entry comment (Notes for this ACL)", "format": "string-rlx"}
    :param dst_object_group: {"description": "Destination network object group name (Source network object group name)", "format": "string", "minLength": 1, "not-list": ["dst-any", "dst-host"], "maxLength": 63, "type": "string"}
    :param any_type: {"default": 0, "not": "icmp-type", "type": "number", "description": "Any ICMP type", "format": "flag"}
    :param dst_any: {"default": 0, "not-list": ["dst-host", "dst-object-group"], "type": "number", "description": "Any destination host", "format": "flag"}
    :param src_host: {"not-list": ["src-any", "src-object-group"], "type": "string", "description": "A single source host (Host address)", "format": "ipv4-address"}
    :param action: {"enum": ["deny", "permit", "l3-vlan-fwd-disable"], "type": "string", "description": "'deny': Deny; 'permit': Permit; 'l3-vlan-fwd-disable': Disable L3 forwarding between VLANs; ", "format": "enum"}
    :param special_code: {"not": "any-code", "enum": ["frag-required", "host-unreachable", "network-unreachable", "port-unreachable", "proto-unreachable", "route-failed"], "type": "string", "description": "'frag-required': Code 4, fragmentation required; 'host-unreachable': Code 1, destination host unreachable; 'network-unreachable': Code 0, destination network unreachable; 'port-unreachable': Code 3, destination port unreachable; 'proto-unreachable': Code 2, destination protocol unreachable; 'route-failed': Code 5, source route failed; ", "format": "enum"}
    :param special_type: {"not": "icmp-type", "enum": ["echo-reply", "echo-request", "info-reply", "info-request", "mask-reply", "mask-request", "parameter-problem", "redirect", "source-quench", "time-exceeded", "timestamp", "timestamp-reply", "dest-unreachable"], "type": "string", "description": "'echo-reply': Type 0, echo reply; 'echo-request': Type 8, echo request; 'info-reply': Type 16, information reply; 'info-request': Type 15, information request; 'mask-reply': Type 18, address mask reply; 'mask-request': Type 17, address mask request; 'parameter-problem': Type 12, parameter problem; 'redirect': Type 5, redirect message; 'source-quench': Type 4, source quench; 'time-exceeded': Type 11, time exceeded; 'timestamp': Type 13, timestamp; 'timestamp-reply': Type 14, timestamp reply; 'dest-unreachable': Type 3, destination unreachable; ", "format": "enum"}
    :param src_eq: {"description": "Match only packets on a given source port (port number)", "format": "number", "not-list": ["src-gt", "src-lt"], "maximum": 65535, "minimum": 1, "type": "number"}
    :param dst_host: {"not-list": ["dst-any", "dst-object-group"], "type": "string", "description": "A single destination host (Host address)", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "rules"
        self.DeviceProxy = ""
        self.geo_location = ""
        self.icmp_type = ""
        self.ip = ""
        self.service_obj_group = ""
        self.dst_eq = ""
        self.tcp = ""
        self.src_range = ""
        self.any_code = ""
        self.src_lt = ""
        self.src_mask = ""
        self.src_port_end = ""
        self.dst_port_end = ""
        self.dst_range = ""
        self.established = ""
        self.dst_mask = ""
        self.seq_num = ""
        self.src_any = ""
        self.fragments = ""
        self.icmp_code = ""
        self.src_gt = ""
        self.udp = ""
        self.dst_subnet = ""
        self.src_subnet = ""
        self.vlan = ""
        self.dscp = ""
        self.dst_lt = ""
        self.icmp = ""
        self.dst_gt = ""
        self.acl_log = ""
        self.src_object_group = ""
        self.remark = ""
        self.dst_object_group = ""
        self.any_type = ""
        self.dst_any = ""
        self.src_host = ""
        self.action = ""
        self.special_code = ""
        self.special_type = ""
        self.src_eq = ""
        self.dst_host = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class AccessList(A10BaseClass):
    
    """Class Description::
    Configure Access List.

    Class access-list supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param rules: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"geo-location": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify geo-location name", "format": "string"}, "icmp-type": {"description": "ICMP type number", "format": "number", "maximum": 254, "minimum": 0, "not": "any-type", "type": "number"}, "ip": {"default": 0, "not-list": ["tcp", "udp", "service-obj-group"], "type": "number", "description": "Any Internet Protocol", "format": "flag"}, "service-obj-group": {"description": "Service object group (Source object group name)", "format": "string", "minLength": 1, "not-list": ["tcp", "udp", "ip"], "maxLength": 63, "type": "string"}, "dst-eq": {"description": "Match only packets on a given destination port (port number)", "format": "number", "not-list": ["dst-gt", "dst-lt"], "maximum": 65535, "minimum": 1, "type": "number"}, "tcp": {"default": 0, "not-list": ["udp", "ip", "service-obj-group"], "type": "number", "description": "protocol TCP", "format": "flag"}, "src-range": {"description": "match only packets in the range of port numbers (Starting Port Number)", "format": "number", "not-list": ["src-eq", "src-gt"], "maximum": 65535, "minimum": 1, "type": "number"}, "any-code": {"default": 0, "not": "icmp-code", "type": "number", "description": "Any ICMP code", "format": "flag"}, "src-lt": {"description": "Match only packets with a lower port number", "format": "number", "not-list": ["src-eq", "src-gt"], "maximum": 65535, "minimum": 2, "type": "number"}, "src-mask": {"type": "string", "description": "Source Mask 0=apply 255=ignore", "format": "ipv4-rev-netmask"}, "src-port-end": {"description": "Ending Port Number", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "dst-port-end": {"description": "Edning Destination Port Number", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "dst-range": {"description": "Match only packets in the range of port numbers (Starting Destination Port Number)", "format": "number", "not-list": ["dst-eq", "dst-gt"], "maximum": 65535, "minimum": 1, "type": "number"}, "established": {"default": 0, "type": "number", "description": "TCP established", "format": "flag"}, "dst-mask": {"type": "string", "description": "Destination Mask 0=apply 255=ignore", "format": "ipv4-rev-netmask"}, "seq-num": {"description": "Sequence Number", "minimum": 1, "type": "number", "maximum": 8192, "format": "number"}, "src-any": {"default": 0, "not-list": ["src-host", "src-object-group"], "type": "number", "description": "Any source host", "format": "flag"}, "fragments": {"default": 0, "type": "number", "description": "IP fragments", "format": "flag"}, "icmp-code": {"description": "ICMP code number", "format": "number", "maximum": 254, "minimum": 0, "not": "any-code", "type": "number"}, "src-gt": {"description": "Match only packets with a greater port number", "format": "number", "not-list": ["src-eq", "src-lt"], "maximum": 65534, "minimum": 1, "type": "number"}, "udp": {"default": 0, "not-list": ["tcp", "ip", "service-obj-group"], "type": "number", "description": "protocol UDP", "format": "flag"}, "dst-subnet": {"not-list": ["dst-any", "dst-host"], "type": "string", "description": "Destination Address", "format": "ipv4-address"}, "src-subnet": {"not-list": ["src-any", "src-host"], "type": "string", "description": "Source Address", "format": "ipv4-address"}, "vlan": {"description": "VLAN ID", "minimum": 1, "type": "number", "maximum": 4094, "format": "number"}, "dscp": {"description": "DSCP", "minimum": 1, "type": "number", "maximum": 63, "format": "number"}, "dst-lt": {"description": "Match only packets with a lesser port number", "format": "number", "not-list": ["dst-eq", "dst-gt"], "maximum": 65535, "minimum": 2, "type": "number"}, "icmp": {"default": 0, "not-list": ["tcp", "udp", "ip", "service-obj-group"], "type": "number", "description": "Internet Control Message Protocol", "format": "flag"}, "optional": true, "dst-gt": {"description": "Match only packets with a greater port number", "format": "number", "not-list": ["dst-eq", "dst-lt"], "maximum": 65534, "minimum": 1, "type": "number"}, "acl-log": {"default": 0, "type": "number", "description": "Log matches against this entry", "format": "flag"}, "src-object-group": {"description": "Network object group (Source network object group name)", "format": "string", "minLength": 1, "not-list": ["src-any", "src-host"], "maxLength": 63, "type": "string"}, "remark": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Access list entry comment (Notes for this ACL)", "format": "string-rlx"}, "dst-object-group": {"description": "Destination network object group name (Source network object group name)", "format": "string", "minLength": 1, "not-list": ["dst-any", "dst-host"], "maxLength": 63, "type": "string"}, "any-type": {"default": 0, "not": "icmp-type", "type": "number", "description": "Any ICMP type", "format": "flag"}, "dst-any": {"default": 0, "not-list": ["dst-host", "dst-object-group"], "type": "number", "description": "Any destination host", "format": "flag"}, "src-host": {"not-list": ["src-any", "src-object-group"], "type": "string", "description": "A single source host (Host address)", "format": "ipv4-address"}, "action": {"enum": ["deny", "permit", "l3-vlan-fwd-disable"], "type": "string", "description": "'deny': Deny; 'permit': Permit; 'l3-vlan-fwd-disable': Disable L3 forwarding between VLANs; ", "format": "enum"}, "special-code": {"not": "any-code", "enum": ["frag-required", "host-unreachable", "network-unreachable", "port-unreachable", "proto-unreachable", "route-failed"], "type": "string", "description": "'frag-required': Code 4, fragmentation required; 'host-unreachable': Code 1, destination host unreachable; 'network-unreachable': Code 0, destination network unreachable; 'port-unreachable': Code 3, destination port unreachable; 'proto-unreachable': Code 2, destination protocol unreachable; 'route-failed': Code 5, source route failed; ", "format": "enum"}, "special-type": {"not": "icmp-type", "enum": ["echo-reply", "echo-request", "info-reply", "info-request", "mask-reply", "mask-request", "parameter-problem", "redirect", "source-quench", "time-exceeded", "timestamp", "timestamp-reply", "dest-unreachable"], "type": "string", "description": "'echo-reply': Type 0, echo reply; 'echo-request': Type 8, echo request; 'info-reply': Type 16, information reply; 'info-request': Type 15, information request; 'mask-reply': Type 18, address mask reply; 'mask-request': Type 17, address mask request; 'parameter-problem': Type 12, parameter problem; 'redirect': Type 5, redirect message; 'source-quench': Type 4, source quench; 'time-exceeded': Type 11, time exceeded; 'timestamp': Type 13, timestamp; 'timestamp-reply': Type 14, timestamp reply; 'dest-unreachable': Type 3, destination unreachable; ", "format": "enum"}, "src-eq": {"description": "Match only packets on a given source port (port number)", "format": "number", "not-list": ["src-gt", "src-lt"], "maximum": 65535, "minimum": 1, "type": "number"}, "dst-host": {"not-list": ["dst-any", "dst-object-group"], "type": "string", "description": "A single destination host (Host address)", "format": "ipv4-address"}}}]}
    :param name: {"description": "IP Access List Name. Does not support name as digits or start with digit.", "format": "string", "minLength": 1, "optional": false, "maxLength": 16, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/ip/access-list/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "access-list"
        self.a10_url="/axapi/v3/ip/access-list/{name}"
        self.DeviceProxy = ""
        self.rules = []
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


